@@ -7,10 +7,11 @@
 #'
 #' @importFrom stats runif
 #'
-#' @param a The binary matrix of all individuals. (matrix)
-#' @param p The mutation rate. (numeric)
-#'
-#' @return Returns a binary matrix with mutated genes. (matrix)
+#' @param a The binary matrix of all individuals.
+#' @param p The mutation rate. 
+#' @param seed Set a seed for comparability. Default is NULL
+#' 
+#' @return Returns a binary matrix with mutated genes. 
 #'
 #' @examples
 #' ## Create 4 random individuals with binary values
@@ -31,15 +32,25 @@
 #' a==aMut
 #'
 #' @author Sebastian Gatscha
-mutation          <- function(a,p) {
+mutation          <- function(a, p, seed) {
+  if (missing(seed)) {
+    seed <- NULL
+  }
   ## Probability for every gene to mutate
   for (i in 1:length(a)) {
     ## for every element in the 2 children, get a random number between 1 & 0
-    rnd <- runif(n = 1,min = 0,max = 1)
+    if (!is.null(seed)) {
+      set.seed(as.integer(seed))
+    }
+    rnd <- runif(n = 1, min = 0, max = 1)
     ## If the random number is smaller than p, the gene is switched
-    ## (from 1 to 0 | from 0 to 1)
+    ## from 1 to 0 | from 0 to 1
     if (rnd < p) {
-      if (a[i] == "0") {a[i] <- 1} else {a[i] <- 0}
+      if (a[i] == "0") {
+        a[i] <- 1
+      } else {
+        a[i] <- 0
+      }
     }
   }
   return(a)
